==> jc-1.4.0.tar.gz: soot/shimple/toolkits/scalar/SEvaluator__24BottomConstant.h <==
// public class soot.shimple.toolkits.scalar.SEvaluator$BottomConstant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class b097c95521162e8d soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant
// @dep_class 430b138846f45212 soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant

// header file dependencies
// @dep_header soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant

#include "soot/shimple/toolkits/scalar/SEvaluator__24MetaConstant.h"

#ifndef _JC_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant_H_
#define _JC_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_Constant$object;
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_refs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$refs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object;

typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$fields_struct	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$fields_struct;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vmethods	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtable	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtype	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtype;

// Class fields structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$fields_struct {
	struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object	*constant;
};
extern _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$fields_struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$class_fields;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object *);

// Virtual methods
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object *, struct _jc_object *);
extern struct _jc_soot_Type$object *_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method_info$getType$847707b1f3b96fef;

// Static methods
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_soot_jimple_Constant$object *_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method$v$9e5d622306b04dbc(_jc_env *);

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object *, struct _jc_object *);
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object *);
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vmethods	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vmethods	soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$refs {
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_refs	soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_refs	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_nonrefs	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_nonrefs	soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object {
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtype _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant_H_ */

==> jc-1.4.6.tar.gz: soot/shimple/toolkits/scalar/SEvaluator__24BottomConstant.h <==
// public class soot.shimple.toolkits.scalar.SEvaluator$BottomConstant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a4a584ce60f6ce4 soot_jimple_Constant
// @dep_class b097c95521162e8d soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant
// @dep_class 430b138846f45212 soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant

// header file dependencies
// @dep_header soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant

#include "soot/shimple/toolkits/scalar/SEvaluator__24MetaConstant.h"

#ifndef _JC_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant_H_
#define _JC_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_Type$object;
struct _jc_soot_jimple_Constant$object;
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_refs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$refs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$refs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$nonrefs	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$nonrefs;
typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object;

typedef struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$fields_struct	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$fields_struct;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vmethods	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vmethods;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtable	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtable;
typedef const struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtype	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtype;

// Class fields structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$fields_struct {
	struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object	*constant;
};
extern _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$fields_struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$class_fields;

// Constructors
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_soot_Type$object *_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method$getType$847707b1f3b96fef(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method_info$getType$847707b1f3b96fef;

// Static methods
extern void _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_Constant$object *_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$method$v$9e5d622306b04dbc(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_soot_Type$object	*(*getType$847707b1f3b96fef)(_jc_env *, struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_Constant$vmethods	soot_jimple_Constant;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$vmethods	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vmethods	soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant;
};

// Vtype
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtype {
	_jc_type			type;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$refs {
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_refs	soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_refs	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
    _jc_soot_jimple_Constant$sub_refs	soot_jimple_Constant;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_Constant$sub_nonrefs	soot_jimple_Constant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant$sub_nonrefs	soot_shimple_toolkits_scalar_SEvaluator__24MetaConstant;
    _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$sub_nonrefs	soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant;
};

// Object instance structure
struct _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$object {
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtype	*vtype;
	_jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$vtype _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant$class_object;

#endif	/* _JC_soot_shimple_toolkits_scalar_SEvaluator__24BottomConstant_H_ */
